@@ -172,11 +172,19 @@ getPixelValue <- function(pt, ds, ri=NULL, band=1, interpolate=FALSE,
     #check that point is inside extent rectangle
     if (ptX > xmax || ptX < xmin) {
         warning("point X value is outside raster extent", call.=FALSE)
-        return(NA)
+        if (windowsize > 1 && is.null(statistic)) {
+          return(rep(NA, windowsize * windowsize))
+        } else {
+          return(NA)
+        }
     }
     if (ptY > ymax || ptY < ymin) {
         warning("point Y value is outside raster extent", call.=FALSE)
-        return(NA)
+        if (windowsize > 1 && is.null(statistic)) {
+          return(rep(NA, windowsize * windowsize))
+        } else {
+          return(NA)
+        }
     }
 
     #get pixel offsets
@@ -200,7 +208,11 @@ getPixelValue <- function(pt, ds, ri=NULL, band=1, interpolate=FALSE,
                 offY < 0 || (offY+windowsize-1) > nrows) {
             warning("window is not completely within raster extent",
                     call.=FALSE)
-            return(NA)
+            if (is.null(statistic) && windowsize > 1) {
+                return(rep(NA, windowsize * windowsize))
+            } else {
+                return(NA)
+            }
         }
     }
 
