@@ -2,47 +2,18 @@
 #' @export
 strat.collapse <- function(stratacnt, pltstratx, minplotnum.unit=10,
 	minplotnum.strat=2, unitarea, areavar, unitvar, unitvar2=NULL, strvar,
-	getwt=FALSE, stratcombine=TRUE, unitcombine=FALSE, vars2combine=NULL, ...) {
+	getwt=FALSE, stratcombine=TRUE, unitcombine=FALSE, stratalevels=NULL,
+	vars2combine=NULL, UNITCD=NULL, ...) {
   ## unitcombine - If TRUE, combine estimation units, If FALSE, only combine strata
 
   ## Set global variables
-  n.strata=n.total=puniqueid=unitstrgrplut=UNITCD=unitnew=strvarnew <- NULL
+  n.strata=n.total=puniqueid=unitstrgrplut=unitnew=strvarnew <- NULL
   addUNITCD <- FALSE
 
   if (!"data.table" %in% class(stratacnt)) stratacnt <- setDT(stratacnt)
   if (!"data.table" %in% class(unitarea)) unitarea <- setDT(unitarea)
 
 
-  ## If number of plots per strata <= minplotnum.strat is more than 50%, collapse to 1 strata.
-#  if (stratcombine && sum(errtab$n.strata < minplotnum.strat)/nrow(stratacnt) >= .5) {
-#    message(paste("number of plots per strata <=", minplotnum,
-#		"is greater than 50%... collapsing strata with less than",
-#		minplotnum, "plots in a strata to 1 strata"))
-#
-#    unitvars <- c(unitvar, unitvar2)
-#    strunitvars <- c(unitvars, strvar)
-#    errtab[, MATCH := do.call(paste, .SD), .SDcols=unitvars]
-#    stratacnt[, MATCH := do.call(paste, .SD), .SDcols=unitvars]
-#    stratacnt[MATCH %in% unique(errtab$MATCH), (strvar) := 1]
-#    stratacnt[, MATCH := NULL]
-#
-#    strsumvars <- c("n.strata", "n.total")
-#    if (getwt) {
-#      strsumvars <- c(vars2combine, strsumvars)
-#    } else {
-#      strsumvars <- c("strwt", strsumvars)
-#    }
-#    strlut <- stratacnt[, lapply(.SD, sum, na.rm=TRUE), by=strunitvars, .SDcols=strsumvars]
-#    pltstratx[, (strvar) := 1]
-#    strlut[, n.strata := NULL][, n.total := NULL]
-#
-#    ## Check again for number of plots by strata. If < 2 plots still with 1 strata, stop.
-#    stratacnts2 <- check.pltcnt(pltx=pltstratx, puniqueid=puniqueid,
-#		unitlut=strlut, unitvars=unitvar, strvars=strvar)
-#    stratacnt <- stratacnts2$unitlut
-#    errtab <- stratacnts2$errtab
-#  }
-
   ## Stop and send message if stratcombine=FALSE
   ######################################################################################
   if (!stratcombine) {
@@ -61,13 +32,13 @@ strat.collapse <- function(stratacnt, pltstratx, minplotnum.unit=10,
   if (!unitcombine) {
     if (any(unique(stratacnt$n.total) < minplotnum.unit)) {
       estunits <- unique(stratacnt[stratacnt$n.total < minplotnum.unit, unitvar, with=FALSE][[1]])
-      stop("estimation unit has less than ", minplotnum.unit, " plots",
-		"... remove or combine estimation units")
-      message(paste(estunits, collapse="; "))
+      message("one or more estimation units has less than ", minplotnum.unit, " plots",
+		         "... set unit_opts(unit.action) to remove or combine estimation units")
+      messagedf(stratacnt[stratacnt[[unitvar]] %in% estunits,])
+      stop()
     }
   }
 
-
   #############################################################################
   ## If stratcombine=TRUE and unitcombine=TRUE and number of total plots is less
   ## than minplotnum.unit.
@@ -87,25 +58,20 @@ strat.collapse <- function(stratacnt, pltstratx, minplotnum.unit=10,
     } else {
       unitcombinevar <- unitvar2
     }
-
-    if (!is.factor(stratacnt[[unitvar]])) {
-      stratacnt[[unitvar]] <- factor(stratacnt[[unitvar]])
-    }
-    stratacnt$unitvar <- as.numeric(stratacnt[[unitvar]])
-    stratacnt$unitnew <- as.character(-1)
-    #setkeyv(stratacnt, c(unitcombinevar, unitvar))
-
-    ## Group estimation units if less than minplotnum
-    unitgrp <- stratacnt[, groupEstunit(.SD, minplotnum.unit), by=UNITCD]
+    
+    ## Group estimation units (by UNITCD) if less than minplotnum
+    unitgrp <- stratacnt[, groupClasses(.SD, minplotnum = minplotnum.unit, 
+                                        nvar="n.total", xvar = unitvar,
+                                        sumvar = "n.strata",
+                                        xvarlevels = NULL), by=UNITCD]
+    setnames(unitgrp, "classnew", "unitnew")
+  
+    ## define collapsed unitvar as 'unitnew'
     unitvarnew <- "unitnew"
-    #setkeyv(unitgrp, c(unitcombinevar, unitvar))
-#    stratacnt <- merge(stratacnt[,unitnew:=NULL],
-#		unitgrp[, c(unitvar, unitcombinevar, "unitvar", unitvarnew), with=FALSE],
-#		by=c(unitvar, unitcombinevar, "unitvar"))
     SDcols <- c(vars2combine, "n.strata", "n.total")
     SDcols <- SDcols[SDcols %in% names(stratacnt)]
     unitgrpsum <- unitgrp[, lapply(.SD, sum, na.rm=TRUE),
-			by=c(unitcombinevar, unitvarnew, strvar), .SDcols=SDcols]
+			           by=c(unitcombinevar, unitvarnew, strvar), .SDcols=SDcols]
     setkeyv(unitgrpsum, c(unitcombinevar, unitvarnew, strvar))
 
     if (addUNITCD) {
@@ -117,8 +83,6 @@ strat.collapse <- function(stratacnt, pltstratx, minplotnum.unit=10,
 
     ## Create look up table with original classes and new classes
     unitgrpvars <- c(unitjoinvars, unitvarnew)
-    #unitgrplut <- unique(stratacnt[, unitgrpvars, with=FALSE])
-    #unitstrgrplut <- unique(stratacnt[, c(unitgrpvars, strvar), with=FALSE])
     unitgrplut <- unique(unitgrp[, unitgrpvars, with=FALSE])
     unitstrgrplut <- unique(unitgrp[, c(unitgrpvars, strvar), with=FALSE])
 
@@ -157,27 +121,25 @@ strat.collapse <- function(stratacnt, pltstratx, minplotnum.unit=10,
 
   #############################################################################
   ## If stratcombine=TRUE and number of total plots is less than minplotnum.strat
+  ## NOTE: minplotnum must not be greater than the minimum number
+  ##		or plots by estimation unit plus 1.
   #############################################################################
-  if ("n.strata" %in% names(unitgrpsum) &&
-		any(unique(unitgrpsum$n.strata) < minplotnum.strat)) {
-   #if ("n.strata" %in% names(unitgrpsum) &&
-	#	any(unique(unitgrpsum$n.strata) < 60)) {
-     
+  if ("n.strata" %in% names(unitgrpsum) && any(unique(unitgrpsum$n.strata) < minplotnum.strat)) {
+    
     tabprint <- TRUE
-
-    unitgrpsum$strat <- unitgrpsum[[strvar]]
-    if (!is.factor(unitgrpsum$strat)) {
-      unitgrpsum$strat <- factor(unitgrpsum$strat)
-    }
-    unitgrpsum$strat <- as.numeric(unitgrpsum$strat)
-    unitgrpsum$stratnew <- as.character(-1)
-
-    stratgrp <- unitgrpsum[, groupStrata(.SD, minplotnum.strat), by=unitvar]
-
+    
+    ## Group strata (by unitvar) if less than minplotnum
+    stratgrp <- unitgrpsum[, groupClasses(.SD, minplotnum = minplotnum.strat, 
+                                        nvar="n.strata", xvar = strvar,
+                                        sumvar = "n.strata",
+                                        xvarlevels = stratalevels), by=unitvar]
+    setnames(stratgrp, "classnew", "stratnew")
+    
+    
     strlut <- stratgrp[, lapply(.SD, sum, na.rm=TRUE),
-		by=c(unitvar, "stratnew"), .SDcols=c(vars2combine, "n.strata")]
+		      by=c(unitvar, "stratnew"), .SDcols=c(vars2combine, "n.strata")]
     strlut[, n.total := stratgrp[match(strlut[[unitvar]], stratgrp[[unitvar]]),
-		"n.total"]]
+		     "n.total"]]
 
 
     ## Create look up table with original classes and new classes
@@ -205,19 +167,22 @@ strat.collapse <- function(stratacnt, pltstratx, minplotnum.unit=10,
     pltstratx <- merge(pltstratx,
 		unique(unitstrgrplut[,c(unitstrjoinvars, "stratnew"), with=FALSE]),
 		by=unitstrjoinvars)
+    
+    ## define collapsed strvar as 'stratnew'
     strvar <- "stratnew"
     strunitvars=c(unitvar, strvar)
+    
   } else {
     strlut <- unitgrpsum
   }
 
   ## Print new table
-  if (tabprint) {
-    msg <- "## new stratalut"
-    message("\n################################### \n",
-            msg, "\n###################################")
-    message(paste0(capture.output(strlut), collapse = "\n"))
-  }
+#  if (tabprint) {
+#    msg <- "## new stratalut"
+#    message("\n################################### \n",
+#            msg, "\n###################################")
+#    message(paste0(capture.output(strlut), collapse = "\n"))
+#  }
  
   returnlst <- list(pltstratx=pltstratx, strlut=strlut, unitvar=unitvar)
   if (!is.null(strvar)) returnlst$strvar <- strvar
@@ -229,3 +194,5 @@ strat.collapse <- function(stratacnt, pltstratx, minplotnum.unit=10,
   }
   return(returnlst)
 }
+
+
