@@ -5,4 +5,6 @@ utils::globalVariables(names(formals(title_options)[1:(length(formals(title_opti
 utils::globalVariables(names(formals(unit_options)[1:(length(formals(unit_options))-1)]))
 utils::globalVariables(names(formals(multest_options)[1:(length(formals(multest_options))-1)]))
 utils::globalVariables(names(formals(spMakeSpatial_options)[1:(length(formals(spMakeSpatial_options))-1)]))
+utils::globalVariables(names(formals(eval_options)[1:(length(formals(eval_options))-1)]))
+utils::globalVariables(names(formals(xy_options)[1:(length(formals(xy_options))-1)]))
 utils::globalVariables(".cl_ds")
\ No newline at end of file
